## Cookies Policy

In accordance with Law Decree n° 196/2003, which replaced the Law n° 675/1996 concerning the protection of personal data, we inform you that by filling out this form and then sending this email message, you consent to the processing of your personal data (sensitive data will not be processed in any way) acquired by GeoSolutions SAS via electronic and/or automated tools. In any case, you can exercise your rights granted to you pursuant to Legislative Decree n° 196/2003 (data access, updates, integration, cancellation). Clicking the “Accept” button, you acknowledge that you have read this text and that you consent to the processing of your personal data. At any time you can ask the staff of GeoSolutions SAS web site to unsubscribe you from the service by following the instructions at the end of each message.

#### Cookies and how they Benefit You

Our website uses cookies, as almost all websites do, to help provide you with the best experience we can. Cookies are small text files that are placed on your computer or mobile phone when you browse websites

Our cookies help us:

- Make our website work as you’d expect
- Remember your settings during and between visits
- Improve the speed/security of the site
- Allow you to share pages with social networks like Facebook

We do not use cookies to:

- Collect any personally identifiable information (without your express permission)
- Collect any sensitive information (without your express permission)
- Pass data to advertising networks
- Pass personally identifiable data to third parties
- Pay sales commissions

You can learn more about all the cookies we use below.

If the settings on your software that you are using to view this website (your browser) are adjusted to accept cookies we take this, and your continued use of our website, to mean that you are fine with this. Should you wish to remove or not use cookies from our site you can learn how to do this below, however doing so will likely mean that our site will not work as you would expect.

#### Our own cookies

We use cookies to make our website work including:

- Remembering your search settings
- Authentication to WMS, WFS, WPS via HTTP requests

There is no way to prevent these cookies being set other than to not use our site.

#### Third Party Cookies

Our site, like most websites, includes functionality provided by third parties. A common example is an embedded YouTube video. Our site includes the following which use cookies:

- Google
- Cloudflare

#### Social Website Cookies

So you can easily like or share our content on the likes of Facebook and Twitter we have included sharing buttons on our site. Cookies are set by:

- Twitter
- Facebook
- Linkedin
- Google +

The privacy implications on this will vary from social network to social network and will be dependent on the privacy settings you have chosen on these networks.

#### Turning Cookies Off

You can usually switch cookies off by adjusting your browser settings to stop it from accepting cookies (learn how here.). Doing so however will likely limit the functionality of our’s and a large proportion of the world’s websites as cookies are a standard part of most modern websites.

It may be that you concerns around cookies relate to so called “spyware”. Rather than switching off cookies in your browser you may find that anti-spyware software achieves the same objective by automatically deleting cookies considered to be invasive. Learn more about managing cookies with antispyware software.